@@ -307,10 +307,10 @@ class _NpnSelectHelper(_CallbackExceptionHelper):
                 instr = _ffi.buffer(in_, inlen)[:]
                 protolist = []
                 while instr:
-                    l = indexbytes(instr, 0)
-                    proto = instr[1:l + 1]
+                    length = indexbytes(instr, 0)
+                    proto = instr[1:length + 1]
                     protolist.append(proto)
-                    instr = instr[l + 1:]
+                    instr = instr[length + 1:]
 
                 # Call the callback
                 outstr = callback(conn, protolist)
@@ -695,7 +695,7 @@ class Context(object):
         """
         Set the passphrase callback
 
-        :param callback: The Python callback to use
+        :param callback: The Python callback to use; must return a byte string
         :param userdata: (optional) A Python object which will be given as
                          argument to the callback
         :return: None
@@ -1080,7 +1080,7 @@ class Context(object):
                 if not push_result:
                     _lib.X509_NAME_free(copy)
                     _raise_current_error()
-        except:
+        except Exception:
             _lib.sk_X509_NAME_free(name_stack)
             raise
 
@@ -1957,9 +1957,7 @@ class Connection(object):
         """
         cert = _lib.SSL_get_peer_certificate(self._ssl)
         if cert != _ffi.NULL:
-            pycert = X509.__new__(X509)
-            pycert._x509 = _ffi.gc(cert, _lib.X509_free)
-            return pycert
+            return X509._from_raw_x509_ptr(cert)
         return None
 
     def get_peer_cert_chain(self):
@@ -1977,8 +1975,7 @@ class Connection(object):
         for i in range(_lib.sk_X509_num(cert_stack)):
             # TODO could incref instead of dup here
             cert = _lib.X509_dup(_lib.sk_X509_value(cert_stack, i))
-            pycert = X509.__new__(X509)
-            pycert._x509 = _ffi.gc(cert, _lib.X509_free)
+            pycert = X509._from_raw_x509_ptr(cert)
             result.append(pycert)
         return result
 
